/* Experiment med drag and drop */
// --------------------------------------------------
// Globala variabler
const trash = ["smörpaket", "tepåse", "bananskal", "mjölkpaket", "kuvert", "dammsugarpåse", "tandborste", "äggkartong", "äggskal"]; // Namn på skräpet
const canTrash = [1, 0, 0, 2, 3, 3, 3, 2, 0]; // Index för sophink som respektive skräp ska läggas i
const can = ["kompost", "plast", "papper", "restavfall"]; // Namn på sophinkar
let msgElem;    // Element för meddelande
let dragElems;  // Array med element som kan dras, dvs img-taggarna med skräp
// --------------------------------------------------
// Initiering då webbsidan laddats in
function init() {
    msgElem = document.querySelector("#message");
    dragElems = document.querySelectorAll("#dragItems img");
    for (let i = 0; i < dragElems.length; i++) {
        dragElems[i].addEventListener("dragstart", dragStart);
        // Obs! Endast händelselyssnare för dragstart läggs på från början
        dragElems[i].draggable = false; // Elementen är ännu inte dragbara
    }
    document.querySelector("#trashBtn").addEventListener("click", newTrash);
} // Slut init
window.addEventListener("load", init);
// --------------------------------------------------
// Ta slumpmässigt fram tre nya sopor
function newTrash() {
    let trashNr;            // Slumpmässigt index till trash-arrayen
    let selectedTrash = []; // Valda sopor i denna omgång
    for (let i = 0; i < 3; i++) { // Ta fram tre sopor
        do {
            trashNr = Math.floor(trash.length * Math.random());
        } while (selectedTrash.includes(trashNr)); // Gå igenom loopen tills tre olika sopor valts
        selectedTrash.push(trashNr);
        dragElems[i].src = "img/sopor/" + trashNr + ".png"; // Visa bilden
        dragElems[i].draggable = true; // Gör elementet dragbart
        dragElems[i].style.opacity = 1; // Skarp bild
        dragElems[i].setAttribute("data-trashnr", trashNr); // Spara skräpets nr (behövs sedan i "drop-delen")
    }
} // Slut newTrash
// --------------------------------------------------
// Hantera en drag-operation
function dragStart(e) {
    msgElem.innerHTML = "";
    let dragElem = this;
    let dropElems = document.querySelectorAll("#dropZones img");
    dragElem.addEventListener("dragend", dragEnd); // Händelselyssnare för avslut av drag-operationen
    for (let i = 0; i < dropElems.length; i++) { // Lägg på händelselyssnare för drop zones
        dropElems[i].addEventListener("dragover", dropZone);
        dropElems[i].addEventListener("dragenter", dropZone);
        dropElems[i].addEventListener("dragleave", dropZone);
        dropElems[i].addEventListener("drop", dropZone);
    }
    // ----------
    // Avsluta drag-operationen
    function dragEnd(e) {
        // Ta bort händelselyssnare för dragend och drop zones.
        // Dessa ska endast vara aktiva då man drar ett element med ett skräp.
        dragElem.removeEventListener("dragend", dragEnd);
        for (let i = 0; i < dropElems.length; i++) {
            dropElems[i].removeEventListener("dragover", dropZone);
            dropElems[i].removeEventListener("dragenter", dropZone);
            dropElems[i].removeEventListener("dragleave", dropZone);
            dropElems[i].removeEventListener("drop", dropZone);
        }
    } // Slut dragEnd
    // ----------
    // Hantera händelser för drop zones
    function dropZone(e) {
        e.preventDefault();
        let dropElem = this;
        switch (e.type) {
            case "dragenter": // Ett element med skräp dras in över en sophink
                dropElem.classList.add("hiliteDropZone");
                break;
            case "dragleave": // Elementet dras bort från sophinken
                dropElem.classList.remove("hiliteDropZone");
                break;
            case "drop": // Elementet släpps på en sophink
                dropElem.classList.remove("hiliteDropZone");
                // Kontrollera om skräpet lagts i rätt hink
                let canNr = dropElem.getAttribute("data-cannr");     // Sophinkens nummer
                let trashNr = dragElem.getAttribute("data-trashnr"); // Skräpets nummer
                if (canTrash[trashNr] == canNr) { // Ligger det i rätt hink?
                    msgElem.innerHTML = "<p>Bra! " + trash[trashNr] + " ska läggas i hinken för " + can[canNr] + ".</p>";
                    dragElem.draggable = false; // Det element som drogs ska, i detta fall, inte längre vara dragbart
                    dragElem.style.opacity = 0.2; // Feedback med svagare bild
                }
                else {
                    msgElem.innerHTML = "<p>Nä, nä... " + trash[trashNr] + " ska INTE läggas i hinken för " + can[canNr] + ".</p><p>Försök igen.</p>";
                }
        } // Slut switch
    } // Slut dropZone
    // ----------
} // Slut dragStart
// --------------------------------------------------
